@@ -4,7 +4,7 @@
  *	  page utilities routines for the postgres inverted index access method.
  *
  *
- * Portions Copyright (c) 2015-2016, Postgres Professional
+ * Portions Copyright (c) 2015-2022, Postgres Professional
  * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -527,7 +527,7 @@ rumInsertValue(Relation index, RumBtree btree, RumBtreeStack * stack,
 			else
 			{
 				BlockNumber	rightrightBlkno = InvalidBlockNumber;
-				Buffer		rightrightBuffer;
+				Buffer		rightrightBuffer = InvalidBuffer;
 
 				/* split non-root page */
 				if (btree->rumstate->isBuild)
