@@ -4,8 +4,8 @@
  *	  fetch tuples from a RUM scan.
  *
  *
- * Portions Copyright (c) 2015-2019, Postgres Professional
- * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
+ * Portions Copyright (c) 2015-2022, Postgres Professional
+ * Portions Copyright (c) 1996-2022, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *-------------------------------------------------------------------------
@@ -22,7 +22,9 @@
 #if PG_VERSION_NUM >= 120000
 #include "utils/float.h"
 #endif
-
+#if PG_VERSION_NUM >= 150000
+#include "common/pg_prng.h"
+#endif
 #include "rum.h"
 
 /* GUC parameter */
@@ -252,6 +254,7 @@ scanPostingTree(Relation index, RumScanEntry scanEntry,
 			RumScanItem	item;
 			Pointer		ptr;
 
+			MemSet(&item, 0, sizeof(item));
 			ItemPointerSetMin(&item.item.iptr);
 
 			ptr = RumDataPageGetData(page);
@@ -464,11 +467,12 @@ collectMatchBitmap(RumBtreeData * btree, RumBtreeStack * stack,
 			char	*ptr = RumGetPosting(itup);
 			RumScanItem item;
 
+			MemSet(&item, 0, sizeof(item));
 			ItemPointerSetMin(&item.item.iptr);
 			for (i = 0; i < RumGetNPosting(itup); i++)
 			{
 				ptr = rumDataPageLeafRead(ptr, scanEntry->attnum, &item.item,
-										  false, rumstate);
+										  true, rumstate);
 				SCAN_ITEM_PUT_KEY(scanEntry, item, idatum, icategory);
 				rum_tuplesort_putrumitem(scanEntry->matchSortstate, &item);
 			}
@@ -1129,7 +1133,12 @@ entryGetNextItemList(RumState * rumstate, RumScanEntry entry, Snapshot snapshot)
 	return true;
 }
 
+#if PG_VERSION_NUM < 150000
 #define rum_rand() (((double) random()) / ((double) MAX_RANDOM_VALUE))
+#else
+#define rum_rand() pg_prng_double(&pg_global_prng_state)
+#endif
+
 #define dropItem(e) ( rum_rand() > ((double)RumFuzzySearchLimit)/((double)((e)->predictNumberResult)) )
 
 /*
